SVN: zope.tales/trunk/setup.py Clean up copy-paste glitches.

Tres Seaver <[email protected]> Tue, 7 Mar 2006 07:56:58 -0500 (EST)
Newsgroups gmane.comp.web.zope.public-cvs
Message-ID <[email protected]>
Log message for revision 65855:
  Clean up copy-paste glitches.

Changed:
  U   zope.tales/trunk/setup.py

-=-
Modified: zope.tales/trunk/setup.py
===================================================================
--- zope.tales/trunk/setup.py	2006-03-07 12:52:32 UTC (rev 65854)
+++ zope.tales/trunk/setup.py	2006-03-07 12:56:58 UTC (rev 65855)
@@ -11,7 +11,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
 """Setup for zope.deprecation package
 
 $Id$
 """
@@ -25,21 +25,23 @@
 except ImportError, e:
     from distutils.core import setup, Extension
 
-setup(name='zope.deprecation',
+setup(name='zope.tales',
       version='3.0',
 
-      url='http://svn.zope.org/zope.deprecation',
+      url='http://svn.zope.org/zope.tales',
       license='ZPL 2.1',
-      description='Zope 3 Deprection Framework',
+      description='Zope 3 Template Application Language Expression Syntax '
+                  '(TALES)',
       author='Zope Corporation and Contributors',
       author_email='[email protected]',
       long_description='',
 
-      packages=['zope', 'zope.deprecation'],
+      packages=['zope', 'zope.tales'],
       package_dir = {'': os.path.join(os.path.dirname(__file__), 'src')},
 
       namespace_packages=['zope',],
       tests_require = ['zope.testing'],
+      install_requires=['zope.interface', 'zope.tal'],
       include_package_data = True,
 
       zip_safe = False,
@@ -11,7 +11,7 @@
 #
 ##############################################################################
-"""Setup for zope.deprecation package
+"""Setup for zope.tales package
 
 $Id$

_______________________________________________
Zope-CVS maillist  -  [email protected]
http://mail.zope.org/mailman/listinfo/zope-cvs

Zope CVS instructions: http://dev.zope.org/CVS